accuracy_by_id: Find best model per id and create forecast out of sample

Description Usage Arguments

View source: R/best_model_per_id.R

Description

Find best model per id and create forecast out of sample

Usage

1
2
3
4
5
6
7
accuracy_by_id(
  forecast_tbl,
  one_obs_id,
  first_date_in_test_set,
  transformation_used,
  model_used
)

Arguments

forecast_tbl

Data frame with all the forecasts by all the models

one_obs_id

Vector of id's with one observation

first_date_in_test_set

The first date in the test set

transformation_used

What transformation, if any, was used. Possibe values are 'none', 'log' or 'log1p'

model_used

Character vector of models used.


vidarsumo/sumots documentation built on June 29, 2021, 4:23 a.m.