create_covid: Creates dummy variable for Covid

Description Usage Arguments

View source: R/create_covid.R

Description

Creates dummy variable for Covid

Usage

1
create_covid(data, fjolda_mork, horizon, freq)

Arguments

data

Data frame with one date column named date and one covid column named covid

fjolda_mork

Threshold for daily covid cases for the dummy to be 1


vidarsumo/sumots documentation built on June 29, 2021, 4:23 a.m.