ml_models_wflw: A function to train simple univariate algorithms

Description Usage Arguments

View source: R/ml_models_wflw.R

Description

train_simple_models() is a function that allows you to train univariate time series models

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
ml_models_wflw(
  recipe_base,
  recipe_spline,
  recipe_lag,
  recipe_both,
  data = training(splits),
  use_models = c("glmnet", "mars", "svm_poly", "svm_rbf", "knn", "rf", "xgboost",
    "cubist", "nnet", "nnetar", "arima_boost", "prophet_boost"),
  skip_models = NULL
)

Arguments

recipe_base

Recipe for the modeltime algorithms and NNETAR

recipe_spline

Recipe with natural spliens

recipe_lag

Recipe with lags

recipe_both

Recipe with splines and lags

data

Data to use

use_models

Models to use

skip_models

Character vector of models to skip, defaults to NULL


vidarsumo/sumots documentation built on June 29, 2021, 4:23 a.m.