View source: R/data_prepared_energy.R
Prepares data for energy forecasting
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | prepare_energy_data(
data,
outcome_var,
horizon,
xreg_tbl = NULL,
slidify_period = NULL,
transformation = "none",
fourier_periods = NULL,
drop_na = TRUE,
use_holidays = FALSE,
holidays_tbl,
pacf_threshold = 0.2,
no_fourier_terms = 10,
fourier_k = 3,
lags_to_use = NULL,
use_own_fourier = FALSE,
own_fourier = NULL
)
|
data |
Data frame to be used. Should contain id column, added if not present |
outcome_var |
Name of the outcome variable. It's renamed as outcome |
horizon |
The forecast horizon denoted as interger value |
xreg_tbl |
Data frame with external regressors |
slidify_period |
Sliding periods used in tk_augment_slidify. If not given c(1/4, 1/3, 1/2, 1) * horizon is used |
transformation |
Transformation to be applied. Defaults to none. Possible values: log, log1p |
pacf_threshold |
Threshold to determine which pacf lags to when creating fourier_period. Defaults to 0.2 |
no_fourier_terms |
Number of fourier periods to include. Defaults to 10 |
fourier_k |
Maximum order(s) of fourier terms |
lags_to_use |
Should lag of outcome variable be used. Defaults to NULL, replace with desired lag |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.