wflw_creator: A helper function to create workflow passed to the ml_tune()...

Description Usage Arguments

View source: R/wflw_creator.R

Description

wflw_creater() is a function that creates workflow

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
wflw_creator(
  model_spec,
  ml_recipe,
  resamples_kfold,
  grid_size = grid_size,
  parallel_type,
  learn_rate,
  min_n,
  tree_depth,
  loss_reduction,
  splits
)

Arguments

model_spec

A model specification created with the Parsnip or Modeltime package

ml_recipe

Recipe for the models

resamples_kfold

Resamples used for tuning parameters

grid_size

The size of the grid of parameters

splits

split object to use


vidarsumo/sumots documentation built on June 29, 2021, 4:23 a.m.