Creates dummy variable for Covid
1 | create_covid(data, fjolda_mork, horizon, freq)
|
data |
Data frame with one date column named date and one covid column named covid |
fjolda_mork |
Threshold for daily covid cases for the dummy to be 1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.