Description Usage Arguments Value
View source: R/stack_ml_models.R
Creates super-learner by stacking differnt ML models
1 2 3 4 5 6 7 8 | stack_ml_models(
submodels_resamples,
kfold,
grid,
models,
parallel = TRUE,
verbose = TRUE
)
|
submodels_resamples |
A modeltime table (mdl_time_tbl) object with a column containing resample results. Created with modeltime_fit_resamples() from the modeltime.resample package |
kfold |
Number of folds in K-fold cross validation |
grid |
Size of grid to tune the meta-learner. Gets passed to tune::tune_grid() |
models |
Which models to try for the meta-learner. Possible choices: glmnet, rf, nnet, xgboost, cubist and svm |
parallel |
Should the calculations be run in parallel. Defaults to TRUE |
verbose |
A logical for logging results as they are generated. Defaults to TRUE |
A list of length two with ensemble accuracy and a modeltime_table to be used for forecasting
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.