Function to tune DeepAR
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 | tune_deepar(
id,
freq,
recipe,
horizon,
splits,
length,
cv_slice_limit,
most_important = TRUE,
assess = "12 weeks",
skip = "4 weeks",
initial = "12 months",
multiple_gpu = FALSE,
no_gpu,
min_obs_cv_train = 1,
clip_gradient = 10,
epochs = NULL,
lookback = NULL,
batch_size = NULL,
learn_rate = NULL,
id_use,
num_cells = NULL,
num_layers = NULL,
scale = NULL,
dropout = NULL
)
|
id |
A quoted column name that tracks the GluonTS FieldName "item_id" |
freq |
A pandas timeseries frequency such as "5min" for 5-minutes or "D" for daily. |
recipe |
A gluonts recipe |
horizon |
The forecast horizon |
length |
The number of distinct hyperparameter for each tunable parameter |
cv_slice_limit |
How many slice/folds in the tsCV |
assess |
The number of samples used for each assessment resample |
skip |
A integer indicating how many (if any) additional resamples to skip to thin the total amount of data points in the analysis resample. |
initial |
The number of samples used for analysis/modeling in the initial resample. |
multiple_gpu |
Should more than one GPU be used |
no_gpu |
How many, if more than one, should be used |
min_obs_cv_train |
Minimum observation in the training set during cross validation |
clip_gradient |
Maximum value of gradient. The gradient is clipped if it is too large (default: 10) |
epochs |
Number of epochs. Importance 1 of 7 |
lookback |
Lookback length. If NULL, will be randomly chosen. Importance 2 of 7 |
batch_size |
batch_size Number of examples in each batch. Importance 3 of 7 |
learn_rate |
Learning rate. Importance 4 of 7 |
id_use |
ID used during training |
num_cells |
Number of RNN cells for each layer. Importance 5 of 7 |
num_layers |
Number of RNN layers. No info on importance |
scale |
Scales numeric data by id group using mean = 0, standard deviation = 1 transformation. No info on importance |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.