Function to tune N-BEATS
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 |
id |
A quoted column name that tracks the GluonTS FieldName "item_id" |
freq |
A pandas timeseries frequency such as "5min" for 5-minutes or "D" for daily. |
recipe |
A gluonts recipe |
horizon |
The forecast horizon |
length |
The number of distinct hyperparameter for each tunable parameter except loss_function which is set to MASE |
cv_slice_limit |
How many slice/folds in the tsCV |
assess |
The number of samples used for each assessment resample |
skip |
A integer indicating how many (if any) additional resamples to skip to thin the total amount of data points in the analysis resample. |
initial |
The number of samples used for analysis/modeling in the initial resample. |
epochs |
Number of epochs |
lookback |
Lookback length. If NULL, will be randomly chosen |
bagging_size |
The number of models that share the parameter combination of 'context_length' and 'loss_function'. |
learn_rate |
Learning rate |
loss_function |
Any of MASE, MAPE sMAPE. Defaults to MASE when loss_function = NULL |
scale |
Scales numeric data by id group using mean = 0, standard deviation = 1 transformation. |
batch_size |
Number of examples in each batch |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.